<p align="center">
  <img src="https://github.com/kaliv0/fumus/blob/main/assets/fumus.gif?raw=true" width="400" alt="Fumus">
</p>

# FUMUS
## Functional Musings in Python


![Python 3.x](https://img.shields.io/badge/python-3.12-blue?style=flat-square&logo=Python&logoColor=white)
[![tests](https://img.shields.io/github/actions/workflow/status/kaliv0/fumus/ci.yml)](https://github.com/kaliv0/fumus/actions/workflows/ci.yml)
[![PyPI](https://img.shields.io/pypi/v/fumus.svg)](https://pypi.org/project/fumus/)

<br><b>Yet another Functional-style Queries API library</b><br>